function [displace_x,displace_y]= find_disp(cr_corr);
% ******************************************************** 
% Function to find peak position
% with a subpixel accuracy in a region of with size 
% equals to n_matrix X n_matrix pixels 
% ********** Parameters **************
% cr_corr       = cross correlation map (same size of the image window)
% displace_x    = displacement in x direction
% displace_x    = displacement in y direction
%**************************************

n_matrix=7; % ALWAYS ODD NUMBERS!!
% around the initial peak
n_pts=size(cr_corr);

zero_displ_x=n_pts(1)/2+1;% center of the cross correlation
zero_displ_y=n_pts(2)/2+1;% center of the cross correlation

% finding first the peak with the coarse resolution of the image (+-1pixel)
[a,b]=max(cr_corr);
[c,coarse_peak_y]=max(a); %line maxima
coarse_peak_x=b(coarse_peak_y); %column of maxima
lim=(n_matrix-1)/2;
    %If too close to alias, then reduce the size of the matrix used in the
    %adjust
    if (coarse_peak_x-lim)<0 | (coarse_peak_x+lim)>(n_pts+1)        
        disp(['Warning-bad correlation Nan x'])
        displace_x=nan;
        displace_y=nan;
        return
    end
    if  coarse_peak_y-lim<=0 | coarse_peak_y+lim>=n_pts+1
        disp(['Warning-bad correlation Nan y'])
        displace_x=nan;
        displace_y=nan;
        return
    end
    % selecting a region around the peak for subpixel search of the peak
    % position
    img_tmp(1:n_matrix,1:n_matrix)=cr_corr(coarse_peak_x-lim:coarse_peak_x+lim,coarse_peak_y-lim:coarse_peak_y+lim);
    
    %**********************************************************************
    %              Fit Options: Gaussian 2D, Whittaker
    %**********************************************************************
    %**********************************************************************
    % Performing the 2D gaussian fit
    %**********************************************************************
    %tol=0.000001;% tolerance of the fitting Tol=0.01  
    %tol=1e-5;% tolerance of the fitting Tol=0.01
    %[cx,cy,sx,sy,PeakOD] = fitgauss2d(img_tmp,tol);
    
    %**********************************************************************
    % Performing the Whittaker fit
    %**********************************************************************
    %tol=1e-4;
    %[cx,cy] = fitwhittaker2d(img_tmp,tol);
    
    %**********************************************************************
    % Performing the Gaussian fit
    %**********************************************************************
    tol=1e-5;
    [cx,cy] = fitgauss1Db(img_tmp,tol);
    
    %**********************************************************************
    
    % correcting the peak position to the reference of the image
    displace_x=(cx-(lim+1)+(coarse_peak_x-zero_displ_x));
    displace_y=((cy-(lim+1))+(coarse_peak_y-zero_displ_y));
         

return
    
