function [c_hor,c_ver] = fitgauss1Db(m,tol)
%*************************************************************
% function to perform a 1D gaussian fit
% to find displacements in x and y directions 
% in a correlation map
% m = image
%tol = fitting tolerance


point=size(m); % size of the matrix
pOD=max(max(m)); %peak value
center_line=floor(point(1)/2)+1; %central line of the matrix
center_column=floor(point(2)/2)+1; %central line of the matrix

vert_dat=m(center_line,1:point(2)); %data used to find vertical position of the peak
hor_dat=m(1:point(1),center_column); % data used to find horizontal peak position

x=1:point(1);
y=1:point(2);

vx=sum(m(:,center_column)); % sum of elements in the column of the peak
vy=sum(m(center_line,:)'); % sum of vertical elements in the line of the peak

c_mass_x= sqrt(sum(vx.*(abs(x-center_line).^2))/sum(vx)); % center of mass x
c_mass_y= sqrt(sum(vy.*(abs(y-center_column).^2))/sum(vy));% center of mass y

hor1D = 1:point(1); % number of horizontal positions
ip1D = [center_line,c_mass_x,pOD]; % data for the minimization
% Adjust of the parameters for minimization (iterative procedure)
options = optimset('Display','off','TolFun',tol,'LargeScale','off');
% procedure to find a minimum of a function given in file @
fp1D = fminunc(@gaussian1d_function,ip1D,options,hor_dat',hor1D);
% peak position in horizontal direction
[c_hor]=fp1D(1);
clear fp1D ip1D

ver1D = 1:point(2);  % number of vertical positions
ip1D = [center_column,c_mass_y,pOD]; % data for the minimization
% procedure to find a minimum of a function given in file @
fp1D = fminunc(@gaussian1d_function,ip1D,options,vert_dat,ver1D);
% peak position in vertical direction
[c_ver]=fp1D(1);

figure
contour(m,10);
hold on
plot(c_ver,c_hor,'xk')
return

