function [cross_corr]= image_cc(frame_a,frame_b)
%****************************************************
% Function to evaluate the cross correlation 
% between a pair of images using the formulation based on FFT
% *******************************************
% Parameters
% frame_a       = Image of the 1st exposure
% frame_b       = Image of the 2nd exposure
% cross_corr    = cross correlation map
%********************************************

% Transforming from image format to double
frame_a=double(frame_a);
frame_b=double(frame_b);

npoints=size(frame_a);

% Removing the mean value. Remember that FFT only makes sense 
fft_frame1=(fft2(frame_a-mean(mean(frame_a))));
fft_frame2=(fft2(frame_b-mean(mean(frame_b))));

% Cross correlation based on Fourier 
conv_frames=(fft_frame2.*conj(fft_frame1))/(npoints(1)*(log10(npoints(1)))^2);

% Adjust of the matrix direction in order to have 0 displacement at the 
%  center of the correlation map
cross_corr=fftshift(abs(ifft2((conv_frames))));

%figure
%colormap('gray')
%pcolor(cross_corr)
%shading flat
return